==> hawkular-btm-fault-detector-0.2.0.Final-sources.jar: org/hawkular/btm/processor/faults/FaultDetector.java <==
/*
 * Copyright 2015 Red Hat, Inc. and/or its affiliates
 * and other contributors as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.hawkular.btm.processor.faults;

import java.util.List;

import javax.inject.Inject;

import org.hawkular.btm.api.model.btxn.BusinessTransaction;
import org.hawkular.btm.server.api.processors.BusinessTransactionFragmentHandler;
import org.jboss.logging.Logger;

/**
 * This class processes business transaction fragments to detect faults and
 * notify them to registered handlers.
 *
 * @author gbrown
 */
public class FaultDetector implements BusinessTransactionFragmentHandler {

    private final Logger log = Logger.getLogger(FaultDetector.class);

    @Inject
    private List<FaultHandler> faultHandlers;

    /**
     * @return the faultHandlers
     */
    public List<FaultHandler> getFaultHandlers() {
        return faultHandlers;
    }

    /**
     * @param faultHandlers the faultHandlers to set
     */
    public void setFaultHandlers(List<FaultHandler> faultHandlers) {
        this.faultHandlers = faultHandlers;
    }

    /* (non-Javadoc)
     * @see org.hawkular.btm.api.processors.BusinessTransactionFragmentHandler#handle(java.lang.String,java.util.List)
     */
    @Override
    public void handle(String tenantId, List<BusinessTransaction> btxns) {
        log.tracef("Fault Detector called with: %s", btxns);
    }

}

==> hawkular-btm-fault-detector-0.3.1.Final-sources.jar: org/hawkular/btm/processor/faults/FaultDetector.java <==
/*
 * Copyright 2015 Red Hat, Inc. and/or its affiliates
 * and other contributors as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.hawkular.btm.processor.faults;

import java.util.List;

import javax.inject.Inject;

import org.hawkular.btm.api.model.btxn.BusinessTransaction;
import org.hawkular.btm.server.api.processors.BusinessTransactionFragmentHandler;
import org.hawkular.btm.server.api.processors.RetryHandler;
import org.jboss.logging.Logger;

/**
 * This class processes business transaction fragments to detect faults and
 * notify them to registered handlers.
 *
 * @author gbrown
 */
public class FaultDetector implements BusinessTransactionFragmentHandler {

    private final Logger log = Logger.getLogger(FaultDetector.class);

    @Inject
    private List<FaultHandler> faultHandlers;

    /**
     * @return the faultHandlers
     */
    public List<FaultHandler> getFaultHandlers() {
        return faultHandlers;
    }

    /**
     * @param faultHandlers the faultHandlers to set
     */
    public void setFaultHandlers(List<FaultHandler> faultHandlers) {
        this.faultHandlers = faultHandlers;
    }

    /* (non-Javadoc)
     * @see org.hawkular.btm.api.processors.BusinessTransactionFragmentHandler#handle(java.lang.String,java.util.List)
     */
    @Override
    public void handle(String tenantId, List<BusinessTransaction> btxns,
            RetryHandler<BusinessTransaction> retryHandler) {
        log.tracef("Fault Detector called with: %s", btxns);
    }

}
